pub struct ProviderRequestPlan {
pub provider_id: String,
pub model_id: String,
pub endpoint: ProviderRequestEndpoint,
pub context: Value,
pub tools: Vec<Value>,
pub options: Value,
pub fingerprint: String,
}Expand description
One material provider request. The fingerprint binds a preflight measurement to exactly the model, endpoint, context, tools, and material request options that will be executed.
Fields
provider_id: Stringmodel_id: Stringendpoint: ProviderRequestEndpointcontext: Valuetools: Vec<Value>options: Valuefingerprint: StringImplementations