Runtime v1 — session event log, execution planes, credential vault, and runner.
Re-exports
pub use archive::ArchiveStore;pub use archive::FileArchiveStore;pub use archive::NullArchiveStore;pub use credential_vault::ChainedCredentialVault;pub use credential_vault::CredentialVault;pub use credential_vault::EnvCredentialVault;pub use credential_vault::InMemoryCredentialVault;pub use execution_plane::ExecutionPlane;pub use execution_plane::LocalExecutionPlane;pub use execution_plane::PermissionRequest;pub use execution_plane::PermissionRequestHandler;pub use execution_plane::PermissionResponse;pub use execution_plane::RunContext;pub use execution_plane::ToolSuspendHandler;pub use execution_plane::ToolSuspendRequest;pub use mcp_proxy_plane::McpProxyPlane;pub use mcp_proxy_plane::McpServerConfig;pub use os_profile::AttentionPolicy;pub use os_profile::GovernancePolicy;pub use os_profile::MemoryWriteRateLimit;pub use os_profile::NativeOsProfile;pub use os_profile::OsProfile;pub use os_profile::SchedulerBudget;pub use os_profile::assert_native_profile;pub use os_profile::default_native_governance_policy;pub use os_profile::governance_filter_schema;pub use os_profile::os_profile;pub use os_profile::DEFAULT_NATIVE_ATTENTION_POLICY;pub use process_sandbox_plane::ProcessSandboxPlane;pub use process_sandbox_plane::SandboxOptions;pub use provider_replay::assistant_replay_key;pub use provider_replay::peek_provider_replay;pub use provider_replay::seed_provider_replay_from_events;pub use remote_vpc_plane::RemoteVpcOptions;pub use remote_vpc_plane::RemoteVpcPlane;pub use replay::is_mid_run;pub use replay::repair_entries;pub use replay::replay_messages;pub use runner::MilestoneEvaluationContext;pub use runner::MilestoneEvaluationHandler;pub use runner::MilestonePolicy;pub use runner::OnTurnMetricsHandler;pub use runner::RuntimeOptions;pub use runner::RuntimeRunner;pub use runner::TurnMetrics;pub use runner::collect_text;pub use sandboxed_skill::PythonSkillPolicy;pub use sandboxed_skill::SkillKind;pub use sandboxed_skill::scan_skill_dir;pub use session_log::FileSessionLog;pub use session_log::InMemorySessionLog;pub use session_log::SessionEntry;pub use session_log::SessionLog;pub use skill_watcher::SkillWatcher;
Modules
- archive
- credential_
vault - eval
judge()— one-shot quality scoring against a goal + criteria.- execution_
plane - large_
result_ spool - mcp_
proxy_ plane - os_
profile - process_
sandbox_ plane - provider_
replay - remote_
vpc_ plane - replay
- replay_
fixture - Fixture helpers for
ReplayProvider. - replay_
provider - ReplayProvider — an LLMProvider that emits previously-recorded assistant messages instead of calling a real LLM API.
- runner
- sandboxed_
skill - session_
log - skill_
watcher